# `crosstown-core`

Core set of functionality shared by the `crosstown` CLI tool and web backend.
Mostly contains information about each package, how to build wheels, and the
tools to build wheels reliably.

## License

LGPL-3.0+
